pub enum PrintingError {
TooManyCharacters(LengthErrorData),
TooLittleCharacters(LengthErrorData),
FailedToGetTerminalDimensions(String),
GridLargerThanTerminal,
NonRectangularGrid,
GridDimensionsNotDefined,
TerminalDimensionsNotDefined,
OriginNotDefined,
}Expand description
These are the possible ways the program can fail.
Each error will contain ‘ErrorData’ which holds the expected and outcome results in the event of the error.
Variants
TooManyCharacters(LengthErrorData)
TooLittleCharacters(LengthErrorData)
FailedToGetTerminalDimensions(String)
GridLargerThanTerminal
NonRectangularGrid
GridDimensionsNotDefined
TerminalDimensionsNotDefined
OriginNotDefined