Module printing_position

Module printing_position 

Structs

PrintingPosition
The PrintingPosition is a way to preset a place to print a grid on the screen with the Printer.

Enums

XPrintingPosition
The list of X positions to print a grid on the screen to.
YPrintingPosition
The list of Y positions to print a grid on the screen to.